library(zoo)
library(Ecfun)
library(EcoHydRology)
library(ggplot2)
library(hydrostats)
library(KFAS)
library(tseries)
library(timeSeries)
library(TSstudio)
library(dplyr)

path <- "../dipwells/"
site <- c("FMIB", "FMAB", "CAAB", "FMR1", "FMR2", "FOIB", "FOAB", "FOR1", "FOR2")
location <- c("FM", "FM", "FM", "FM", "FM", "FO", "FO", "FO", "FO", "FO")
type <- c("IB", "AB", "AB", "R", "R", "IB", "AB", "R", "R")
dfAll <- data.frame()
SY <- c(0.075801, 0.092558, 0.092558, 0.144868, 0.084428, 0.095331, 0.086749, 0.084188, 0.088224)
#FMAB	.092558
#FMIB	.075801
#FMR1	.144868
#FMR2	.084428
#FOAB	.086749
#FOIB	.095331
#FOR1	.084188
#FOR2	.088224



# Zoo object to data frame helper function
zoo.to.data.frame <- function(x, index.name="Date") {
  stopifnot(is.zoo(x))
  xn <- if(is.null(dim(x))) deparse(substitute(x)) else colnames(x)
  setNames(data.frame(index(x), x, row.names=NULL), c(index.name,xn))
}

# Set time zone
Sys.setenv(TZ = "GMT")

for (i in 1:length(file)) {
  
  # Read in precipitation (P) and discharge (WTD)
  wtdat <- read.table(paste(path, site[i], ".csv", sep=""), header = TRUE, sep = ",", as.is = TRUE)
  
  # Interploate any missing values
  wtdat$WTD <- na.approx(wtdat$WTD, rule=2)
  
  # Replace any missing P values with zeros
  wtdat$P[is.na(wtdat$P)] = 0
  
  # Format date_times
  wtdat$Date <- as.POSIXct(wtdat$Date, "%d/%m/%Y %H:%M", tz="GMT")
  
  # Create time series for PQ
  tsWTD <- zoo(x = wtdat[, 2:3], order.by = wtdat$Date)
  
  # Water year
  win <- window(tsWTD, start = as.POSIXct("2018-10-01"), end = as.POSIXct("2019-09-30"))
  
  # Convert back to data frame
  df <- zoo.to.data.frame(win)
  
  # Diff
  diff <- df$WTD[-1] - df$WTD[-length(df$WTD)]
  diff <- diff * SY[i]
  
  # Storage change
  SC <- sum(diff, na.rm = TRUE)
  
  # Create data table
  dfRow <- data.frame(Site = site[i], SC = SC * 10)
  dfAll <- bind_rows(dfAll, dfRow)
}

# Write to SPSS
write.csv(dfAll, paste(path, "storage_change.csv", sep=""))






